<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/revisions?lang_cible=eu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// D
	'diff_para_ajoute' => 'Paragrafo bat erantsi egin da',
	'diff_para_deplace' => 'Paragrafo murgildua',
	'diff_para_supprime' => 'Paragrafo ezabatua',
	'diff_texte_ajoute' => 'Testua erantsita',
	'diff_texte_deplace' => 'Mugitua izan den textua',
	'diff_texte_supprime' => 'Testuaezabatua',

	// I
	'info_historique' => 'Berrikuspenak :',
	'info_historique_lien' => 'Aldaketen zerrenda erakutsi',
	'info_historique_titre' => 'Berrikuspenen jarraipena',

	// V
	'version_deplace_rubrique' => '<b>« @from@ »</b>-etik <b>« @to@ »</b>-era mugitua.',
	'version_initiale' => 'Hasierako bertsioioa'
);

?>
